# $Id: suphp.spec 3469 2005-08-11 22:23:52Z dag $
# Authority: dag

%{?el4:%define _without_apr1 1}
%{?el3:%define _without_apr1 1}

%define real_name suphp

Summary: Apache module that enables running PHP scripts under different users
Name: mod_suphp
Version: 0.7.2
Release: 19%{?dist}
License: GPL/Apache License
Group: System Environment/Daemons
URL: http://www.suphp.org/

Packager: Michael Stauber <mstauber@blueonyx.it>
Vendor: Team BlueOnyx, http://www.blueonyx.it/

Source: http://projects.marsching.org/suphp/download/suphp-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: httpd-devel >= 2.0, gcc-c++, automake, autoconf, shtool
Requires: httpd >= 2.0, php

Patch0: mod_suphp-apache24.patch

%description
The suPHP Apache module together with suPHP itself provides an easy way to
run PHP scripts with different users on the same server. It provides security,
because the PHP scripts are not run with the rights of the webserver's user.
In addition to that you probably won't have to use PHP's "safe mode", which
applies many restrictions on the scripts.

%prep
%setup -n %{real_name}-%{version}
%patch0 -p0

%{__cat} <<EOF >suphp.conf
[global]
logfile=%{_localstatedir}/log/httpd/suphp_log
loglevel=info
webserver_user=apache
docroot=/
env_path=/bin:/usr/bin
umask=0022
min_uid=500
min_gid=500

; Security options
allow_file_group_writeable=true   
allow_file_others_writeable=false
allow_directory_group_writeable=true
allow_directory_others_writeable=false

;Check wheter script is within DOCUMENT_ROOT
check_vhost_docroot=true

;Send minor error messages to browser
errors_to_browser=true

[handlers]
;Handler for php-scripts
x-httpd-suphp="php:%{_bindir}/php-cgi"
x-httpd-suphp="php:/usr/bin/php-cgi"
x-httpd-suphp-7.4="php:/home/solarspeed/php-7.4/bin/php-cgi"
x-httpd-suphp-8.0="php:/home/solarspeed/php-8.0/bin/php-cgi"
x-httpd-suphp-8.1="php:/home/solarspeed/php-8.1/bin/php-cgi"
x-httpd-suphp-8.2="php:/home/solarspeed/php-8.2/bin/php-cgi"
x-httpd-suphp-8.3="php:/home/solarspeed/php-8.3/bin/php-cgi"
x-httpd-suphp-8.4="php:/home/solarspeed/php-8.4/bin/php-cgi"
x-httpd-suphp-8.5="php:/home/solarspeed/php-8.5/bin/php-cgi"
x-httpd-suphp-8.6="php:/home/solarspeed/php-8.6/bin/php-cgi"
x-httpd-suphp-8.7="php:/home/solarspeed/php-8.7/bin/php-cgi"
x-httpd-suphp-8.8="php:/home/solarspeed/php-8.8/bin/php-cgi"
x-httpd-suphp-8.9="php:/home/solarspeed/php-8.9/bin/php-cgi"
x-httpd-suphp-9.0="php:/home/solarspeed/php-9.0/bin/php-cgi"
x-httpd-suphp-9.1="php:/home/solarspeed/php-9.1/bin/php-cgi"
x-httpd-suphp-9.2="php:/home/solarspeed/php-9.2/bin/php-cgi"
x-httpd-suphp-9.3="php:/home/solarspeed/php-9.3/bin/php-cgi"
x-httpd-suphp-9.4="php:/home/solarspeed/php-9.4/bin/php-cgi"

;Handler for CGI-scripts
x-suphp-cgi="execute:!self"

EOF

%{__cat} <<EOF >suphp.httpd
# This is the Apache server configuration file providing suPHP support.
# It contains the configuration directives to instruct the server how to
# serve php pages while switching to the user context before rendering.

LoadModule suphp_module modules/mod_suphp.so

# This option tells mod_suphp if a PHP-script requested on this server (or
# VirtualHost) should be run with the PHP-interpreter or returned to the
# browser "as it is".
suPHP_Engine off

# Disable php when suphp is used, to avoid having both.
#<IfModule mod_php5.c>
#php_admin_flag engine off
#</IfModule>
#<IfModule mod_php4.c>
#php_admin_flag engine off
#</IfModule>

# To use suPHP to parse PHP-Files
#AddHandler x-httpd-php .php
#AddHandler x-httpd-php .php .php4 .php3 .phtml

#suPHP_AddHandler x-httpd-php
#suPHP_UserGroup apache apache

# This option tells mod_suphp which path to pass on to the PHP-interpreter
# (by setting the PHPRC environment variable).
# Do *NOT* refer to a file but to the directory the file resides in.
#
# E.g.: If you want to use "/path/to/server/config/php.ini", use "suPHP_Config
# /path/to/server/config".
#
# If you don't use this option, PHP will use its compiled in default path.
# suPHP_ConfigPath /etc

# If you compiled suphp with setid-mode "force" or "paranoid", you can
# specify the user- and groupname to run PHP-scripts with.
# Example: suPHP_UserGroup foouser bargroup
# suPHP_UserGroup apache apache

# This option tells mod_suphp to handle requests with the type <mime-type>.
# Please note this only works, if an action for the handler is specified
# in the suPHP configuration file.
# suPHP_AddHandler x-httpd-php

# This option tells mod_suphp to NOT handle requests with the type <mime-type>.
# suPHP_RemoveHandler <mime-type>
EOF

# In %build, updated configure to remove --with-php
%build
export CPPFLAGS="-I/usr/include/apr-0 -I/usr/include/apr-1"
export CXXFLAGS="-std=c++11 -no-pie -fPIC -Wno-unused-variable"
aclocal
libtoolize --force
autoconf
autoheader
automake --add-missing
%configure \
	--disable-checkpath \
	--with-apache-user="apache" \
	--with-apr="%{_bindir}/apr-1-config" \
	--with-apxs="%{_bindir}/apxs" \
	--with-logfile="%{_localstatedir}/log/httpd/suphp_log" \
	--with-min-uid="501" \
	--with-min-gid="500" \
	--with-setid-mode="paranoid"

# Its apache2!!!
sed -i 's/^MAYBE_AP.*/MAYBE_AP\ =\ apache2/g' src/Makefile

%{__make} %{?_smp_mflags} clean all

%install
%{__rm} -rf %{buildroot}
%{__make} install DESTDIR="%{buildroot}"

%{__install} -Dp -m0644 suphp.conf %{buildroot}%{_sysconfdir}/suphp.conf
%{__install} -Dp -m0644 suphp.httpd %{buildroot}%{_sysconfdir}/httpd/conf.d/suphp.conf

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-, root, root, 0755)
%doc AUTHORS ChangeLog COPYING doc/ NEWS README
%config(noreplace) %{_sysconfdir}/suphp.conf
%config(noreplace) %{_sysconfdir}/httpd/conf.d/suphp.conf
%{_libdir}/httpd/modules/mod_suphp.so
%{_sbindir}/suphp

%changelog

* Wed Jun 18 2025 Michael Stauber <mstauber@blueonyx.it> 0.7.2-19
- Rebuilt for BlueOnyx 5212R on AlmaLinux 10
- Added mod_suphp-apache24.patch for Apache 2.4 compatibility
- Updated patch application to use %patch 0 -p0
- Removed --with-php configure option (unrecognized)

* Mon Oct 10 2022 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX18
- Reverted back to our 5210R sources from 0.7.2-0BX16
- Added 'export CXXFLAGS="-std=c++11 -no-pie -fPIC"' to get it to compile

* Sun Dec 19 2021 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX17
- Build for 5211R on RHEL9.
- Based on mod_suphp-0.7.2-16.fc35.src.rpm with our changes merged in

* Fri Nov 16 2018 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX16
- Build for 5210R on RHEL8. Added 'libtoolize --force'

* Tue Mar 10 2015 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX15
- Updated version with support for multiple PHP versions.

* Wed Jan 28 2015 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX14
- Rebuild with different flags.

* Wed Jan 28 2015 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX13
- Totally revised config for 5209R on EL7.

* Wed Jul 16 2014 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX12
- Applied patch to allow build against Apache 2.4.
- Tweaked build options to allow compile to finish.
- See: https://lists.marsching.com/pipermail/suphp/2013-May/002553.html

* Thu Aug 30 2012 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX11
- Extended suphp-0.7.1/src/Application.cpp error message with notice about 'Web Ownership'.

* Sun Jul 24 2011 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX10
- Config norplace makes it necessary to run a search and replace on /etc/suphp.conf as well.

* Sun Jul 24 2011 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX09
- Changed umask in /etc/suphp.conf from 077 to 022.

* Mon Jul 05 2010 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX08
- Added logrotate for suPHP
- PHP session directory needs to be world writeable if we run php-cgi

* Sun Jul 04 2010 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX07
- Removed handler for an optional third party PHP
- Was a stupid idea as it would need changes in three different modules.
- Third party PHP installs must instead modify /etc/suphp.conf instead, which is much easier.

* Sun Jul 04 2010 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX06
- Added handler for an optional third party PHP
- This is necessary as suPHP will otherwise always use the onboard PHP

* Sun Jul 04 2010 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX05
- Changed 'errors_to_browser' to 'true' in /etc/suphp.conf
- While this may lead to an information disclosure, it also makes sure that site and server admins see why their site doesn't run anymore.
- So this is - for now - an acceptable drawback.

* Sat Jul 03 2010 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX04
- Apache restart added to post-install and post-uninstall

* Sat Jul 03 2010 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX03
- More tweaks:
- Minimum user ID is now 501, so that scripts owned by 'admin' are not executed for security reasons.
- Since suPHP-0.7.0 handler definitions in /etc/suphp.conf must be escaped with double-ticks
- We use /usr/bin/php-cgi as handler for PHP if suPHP is enabled
- Switched from paranoid to owner and use --enable-SUPHP_USE_USERGROUP=yes as well
- Commented out all unneeded definitions from /etc/httpd/conf.d/suphp.conf as we use all relevant options in the VHost containers

* Sat Jul 03 2010 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX02
- General option tweaking

* Sat Jul 03 2010 Michael Stauber <mstauber@blueonyx.it> 0.7.2-0BX01
- Updated to release 0.7.1

